PyXMake Developer Guide: PyXMake.Tools.ErrorHandling.InputError Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Member Functions | Public Attributes | List of all members
PyXMake.Tools.ErrorHandling.InputError Class Reference

Base class for all input errors. More...

Inheritance diagram for PyXMake.Tools.ErrorHandling.InputError:

## Public Member Functions
def | __init__ (self, Expression)
Public Member Functions inherited from PyXMake.Tools.ErrorHandling.Error
def | __getstate__ (self)
def | __setstate__ (self, _dict)

## Public Attributes
| Expression
| Input expression in which the error occurred. More...

## Detailed Description

Base class for all input errors.

    Exception raised for errors in the input.

    Attributes:
    Expression -- Input expression in which the error occurred

Inherited from Error.

Definition at line 60 of file ErrorHandling.py.

## Constructor & Destructor Documentation

## ◆ __init__()

def PyXMake.Tools.ErrorHandling.InputError.__init__ | ( |  | self,
|  |  | Expression
| ) |  |

    Low-level initialization of input error class.

Definition at line 67 of file ErrorHandling.py.

## Member Data Documentation

## ◆ Expression

PyXMake.Tools.ErrorHandling.InputError.Expression

Input expression in which the error occurred.

This is the internal error code.

Definition at line 72 of file ErrorHandling.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/Tools/ErrorHandling.py